@@ -60,7 +60,7 @@ on_protocol_button_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 	g_print ("name: %s\n", gtk_widget_get_name (parent));
 	child = gtk_bin_get_child (GTK_BIN (parent));
 	
-	gtk_widget_ref (child);
+	g_object_ref (child);
 	
 	gtk_container_remove (GTK_CONTAINER (parent), child);
 	*/
@@ -80,7 +80,7 @@ on_protocol_button_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 		gtk_tree_view_set_model (widget, multicast_model); */
 	}
 	
-	/* gtk_widget_unref (child); */
+	/* g_object_unref (child); */
 }
 
 static NetstatOption
@@ -123,7 +123,7 @@ netstat_get_active_option (Netinfo * netinfo)
 	}
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (netinfo->protocol))) {
 		/* Only works for Solaris */
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
 	    	option = g_strdup ("-a -f inet -ln");
 #else
 		if (netinfo_is_ipv6_enable ()) {
@@ -292,7 +292,7 @@ netstat_protocol_tree_insert (GtkTreeView *widget, gchar *line)
 	g_return_if_fail (line != NULL);
 
 	count = strip_protocol_line (line, &data);
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
 	if (count == 5 || count == 6 || count == 9 || count == 10) {
 #else
 	if (count == 5 || count == 6) {
@@ -360,7 +360,7 @@ static gint
 strip_protocol_line (gchar * line, netstat_protocol_data *data)
 {
 	gint count = 0;
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
 	gint a1, a2, a3, a4;
 	gchar s9[30];
 #else
@@ -371,7 +371,7 @@ strip_protocol_line (gchar * line, netstat_protocol_data *data)
 
 	/*line = g_strdelimit (line, ":", ' ');*/
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
 	line = g_strdelimit (line, ":", ' ');
 	
 	count = sscanf (line, NETSTAT_PROTOCOL_FORMAT,
@@ -485,7 +485,7 @@ netstat_route_tree_insert (GtkTreeView *widget, gchar *line)
 	g_return_if_fail (line != NULL);
 
 	count = strip_route_line (line, &data);
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
 	if (count == 6) {
 #else
 	if ((count == 8) || (count == 7)) {
@@ -532,6 +532,7 @@ netstat_route_tree_insert (GtkTreeView *widget, gchar *line)
 							 (model),
 							 &iter,
 							 &sibling);
+			gtk_tree_path_free (path);
 		} else {
 			gtk_list_store_append (GTK_LIST_STORE
 						   (model), &iter);
@@ -561,7 +562,7 @@ strip_route_line (gchar * line, netstat_route_data *data)
 	gchar **items;
 #endif
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
 	count = sscanf (line, NETSTAT_ROUTE_FORMAT,
 			data->destination,
 			data->gateway, flags,
@@ -604,7 +605,7 @@ netstat_create_route_model (GtkTreeView *widget)
 	renderer = gtk_cell_renderer_text_new ();
 	column =
 	    gtk_tree_view_column_new_with_attributes
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
 	    (_("Destination/Prefix"), renderer, "text", 0, NULL);
 #else
 	    (_("Destination"), renderer, "text", 0, NULL);
@@ -618,7 +619,7 @@ netstat_create_route_model (GtkTreeView *widget)
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (widget, column);
 
-#ifndef __FreeBSD__
+#if ! (defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__)) || defined(__NetBSD__) || defined(__DragonFly__)
 	renderer = gtk_cell_renderer_text_new ();
 	column =
 	    gtk_tree_view_column_new_with_attributes
