@@ -24,22 +24,32 @@
 #include "nettool.h"
 
 /* The ping usage and output is different between Unix flavours */
-/* FIXME: Add BSD support */
-#if defined(__linux__) || defined(__OSF__) || defined(__FreeBSD__)
-#   define PING_PROGRAM_FORMAT "%s ping -c %d -n %s"
-#   define PING_PROGRAM_FORMAT_6 "%s ping6 -c %d -n %s"
+#if defined(__linux__)
+    /*  <path to program> ping -b [-c <count>] -n <host> */
+#   define PING_PROGRAM_FORMAT "%s ping -b%s-n %s"
+#   define PING_PROGRAM_FORMAT_6 "%s ping6%s-n %s"
+#   define PING_FORMAT "%d bytes from %s icmp_seq=%d ttl=%d time=%s %s"
+#   define PING_PARAMS_6
+#elif defined(__OSF__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
+    /*  <path to program> ping [-c <count>] -n <host> */
+#   define PING_PROGRAM_FORMAT "%s ping%s-n %s"
+#   define PING_PROGRAM_FORMAT_6 "%s ping6%s-n %s"
 #   define PING_FORMAT "%d bytes from %s icmp_seq=%d ttl=%d time=%s %s"
 #   define PING_PARAMS_6
 #elif defined(__sun__) 
-#   define PING_PROGRAM_FORMAT "%s ping -s -n %s 56 %d"
+    /*  <path to program> ping -s -n <host> [<count>] */
+#   define PING_PROGRAM_FORMAT "%s ping -s -n %s 56%s"
+#   define PING_PROGRAM_FORMAT_6 "%s ping -s -A inet6 -a -n %s 56%s"
 #   define PING_FORMAT "%d bytes from %s icmp_seq=%d. time=%f %s"
 #   define PING_PARAMS_5
 #elif defined(__hpux__)
-#   define PING_PROGRAM_FORMAT "%s ping %s -n %d"
+#   define PING_PROGRAM_FORMAT "%s ping %s -n%s"
+#   define PING_PROGRAM_FORMAT_6 "%s ping %s -f inet6 -n%s"
 #   define PING_FORMAT "%d bytes from %s icmp_seq=%d. time=%f %s"
 #   define PING_PARAMS_5
 #else
-#   define PING_PROGRAM_FORMAT "%s ping -c %d -n %s"
+#   define PING_PROGRAM_FORMAT "%s ping %s -n %s"
+#   define PING_PROGRAM_FORMAT_6 "%s ping6 %s -n %s"
 #   define PING_FORMAT "%d bytes from %s icmp_seq=%d. time=%f %s"
 #   define PING_PARAMS_5
 #endif
@@ -61,6 +71,8 @@ struct _ping_data {
 /* Ping funtions */
 void ping_do (Netinfo * netinfo);
 void ping_stop (Netinfo * netinfo);
-void ping_foreach (Netinfo * netinfo, gchar * line, gint len, gpointer user_data);
+void ping_foreach (Netinfo * netinfo, gchar * line, gssize len, gpointer user_data);
 void ping_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len, gpointer user_data);
 void ping_copy_to_clipboard (Netinfo * netinfo, gpointer user_data);
+gint on_ping_graph_expose (GtkWidget *widget, GdkEventExpose *event, 
+			   Netinfo *info);
